summaryrefslogtreecommitdiffstats
path: root/src/plugins/multimedia/gstreamer/common/qgstreamervideosink.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/plugins/multimedia/gstreamer/common/qgstreamervideosink.cpp')
-rw-r--r--src/plugins/multimedia/gstreamer/common/qgstreamervideosink.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/plugins/multimedia/gstreamer/common/qgstreamervideosink.cpp b/src/plugins/multimedia/gstreamer/common/qgstreamervideosink.cpp
index a4268db34..21b64f997 100644
--- a/src/plugins/multimedia/gstreamer/common/qgstreamervideosink.cpp
+++ b/src/plugins/multimedia/gstreamer/common/qgstreamervideosink.cpp
@@ -86,12 +86,12 @@ QGstreamerVideoSink::QGstreamerVideoSink(QVideoSink *parent)
}
bool disablePixelAspectRatio =
- qEnvironmentVariableIsSet("QT_MULTIMEDIA_GSTREAMER_DISABLE_PIXEL_ASPECT_RATIO");
+ qEnvironmentVariableIsSet("QT_GSTREAMER_DISABLE_PIXEL_ASPECT_RATIO");
if (disablePixelAspectRatio) {
// Enabling the pixel aspect ratio may expose a gstreamer bug on cameras that don't expose a
// pixel-aspect-ratio via `VIDIOC_CROPCAP`. This can cause the caps negotiation to fail.
// Using the QT_MULTIMEDIA_GSTREAMER_DISABLE_PIXEL_ASPECT_RATIO environment variable, on can
// disable pixel-aspect-ratio handling
//
// compare: https://gitlab.freedesktop.org/gstreamer/gstreamer/-/merge_requests/6242
gstCapsFilter =
@@ -86,12 +86,12 @@ QGstreamerVideoSink::QGstreamerVideoSink(QVideoSink *parent)
// Enabling the pixel aspect ratio may expose a gstreamer bug on cameras that don't expose a
// pixel-aspect-ratio via `VIDIOC_CROPCAP`. This can cause the caps negotiation to fail.
- // Using the QT_MULTIMEDIA_GSTREAMER_DISABLE_PIXEL_ASPECT_RATIO environment variable, on can
- // disable pixel-aspect-ratio handling
+ // Using the QT_GSTREAMER_DISABLE_PIXEL_ASPECT_RATIO environment variable, one can disable
+ // pixel-aspect-ratio handling
//
// compare: https://gitlab.freedesktop.org/gstreamer/gstreamer/-/merge_requests/6242